==> aria2_1.10.0.orig.tar.gz: aria2-1.10.0/src/DHTReplaceNodeTask.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_DHT_REPLACE_NODE_TASK_H_
#define _D_DHT_REPLACE_NODE_TASK_H_

#include "DHTAbstractTask.h"
#include "a2time.h"

namespace aria2 {

class DHTBucket;
class DHTPingReplyMessage;

class DHTReplaceNodeTask:public DHTAbstractTask {
private:
  SharedHandle<DHTBucket> bucket_;

  SharedHandle<DHTNode> newNode_;

  static const size_t MAX_RETRY = 2;

  size_t numRetry_;

  time_t timeout_;

  void sendMessage();
public:
  DHTReplaceNodeTask(const SharedHandle<DHTBucket>& bucket,
                     const SharedHandle<DHTNode>& newNode);

  virtual ~DHTReplaceNodeTask();

  virtual void startup();

  void onReceived(const DHTPingReplyMessage* message);

  void onTimeout(const SharedHandle<DHTNode>& node);  

  void setTimeout(time_t timeout)
  {
    timeout_ = timeout;
  }
};

} // namespace aria2

#endif // _D_DHT_REPLACE_NODE_TASK_H_

==> aria2_1.35.0.orig.tar.gz: aria2-1.35.0/src/DHTReplaceNodeTask.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_DHT_REPLACE_NODE_TASK_H
#define D_DHT_REPLACE_NODE_TASK_H

#include "DHTAbstractTask.h"
#include "a2time.h"

namespace aria2 {

class DHTBucket;
class DHTPingReplyMessage;

class DHTReplaceNodeTask : public DHTAbstractTask {
private:
  std::shared_ptr<DHTBucket> bucket_;

  std::shared_ptr<DHTNode> newNode_;

  int numRetry_;

  std::chrono::seconds timeout_;

  void sendMessage();

public:
  DHTReplaceNodeTask(const std::shared_ptr<DHTBucket>& bucket,
                     const std::shared_ptr<DHTNode>& newNode);

  virtual ~DHTReplaceNodeTask();

  virtual void startup() CXX11_OVERRIDE;

  void onReceived(const DHTPingReplyMessage* message);

  void onTimeout(const std::shared_ptr<DHTNode>& node);

  void setTimeout(std::chrono::seconds timeout)
  {
    timeout_ = std::move(timeout);
  }
};

} // namespace aria2

#endif // D_DHT_REPLACE_NODE_TASK_H
